WriteAction

Enum WriteAction 

pub enum WriteAction {
    Write(usize),
}
A writer operation used by write behavior tests.

Variants



Write(usize)

Write a buffer with the given size.

A writer can accept the buffer incrementally even though the action supplies it as one logical chunk.