ReadChecker

Struct ReadChecker 

pub struct ReadChecker { /* private fields */ }
ReadChecker is used to check the correctness of the read process.

Implementations

Source

impl ReadChecker

pub fn new(size: usize) -> Self

Create a new read checker by given size and range.

It’s by design that we use a random generator to generate the raw data. The content of data is not important, we only care about the correctness of the read process.

pub fn data(&self) -> Bytes

Return the raw data of this read checker.

pub async fn check(&mut self, r: Reader, actions: &[ReadAction])

Check will check the correctness of the read process via given actions.

Check will panic if any check failed.