opendal-testkit 0.59.0

Test harness and utilities for Apache OpenDAL
docs.rs failed to build opendal-testkit-0.59.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: opendal-testkit-0.58.2

Apache OpenDAL™ Testkit

opendal-testkit provides reusable test actions, data checkers, runtime setup, and service initialization helpers for Apache OpenDAL™ storage implementations.

This crate is intended for service and integration tests. It is not required by applications using an OpenDAL operator.

Add it as a development dependency:

cargo add --dev opendal-testkit

The opendal facade also re-exports the testkit behind its tests feature.

Documentation

License

Licensed under the Apache License, Version 2.0.