Crate opendal_testkit

Crate opendal_testkit 

Test harness and utilities for Apache OpenDAL.

Structs

ReadChecker
ReadChecker is used to check the correctness of the read process.
WriteChecker
WriteAction is used to check the correctness of the write process.

Enums

ReadAction
ReadAction represents a read action.
WriteAction
WriteAction represents a read action.

Statics

TEST_RUNTIME
TEST_RUNTIME is the runtime used for running tests.

Functions

init_test_service
Init a service with given scheme.