ReadAction

Enum ReadAction 

pub enum ReadAction {
    Read(usize, usize),
}
ReadAction represents a read action.

Variants



Read(usize, usize)

Read represents a read action with given input buf size.

NOTE

The size is the input buf size, it’s possible that the actual read size is smaller.