pub enum ReadAction {
Read(usize, usize),
}Expand description
A reader operation executed by ReadChecker.
Variants
Read(usize, usize)
Read size bytes beginning at offset.
The first field is the offset and the second field is the requested size. A reader can return fewer bytes at the end of an object.