pub enum WriteAction {
Write(usize),
}Expand description
WriteAction represents a read action.
Variants
Write(usize)
Write represents a write action with given input buf size.
NOTE
The size is the input buf size, it’s possible that the actual write size is smaller.